<?xml version="1.0" encoding="ISO-8859-1" ?>
<?rscvt type="out-filter" version="1.0" name="Topcon Koordinaten (.kor)" file-ext="*.kor;" cmd-ext="kor_out" ?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xlink="http://ww.w3.org/TR/xlink" version="1.0">
	<!-- Ausgabe - Deklarationen -->
	<xsl:output method="text" encoding="ISO-8859-1"/>
	<xsl:strip-space elements="*"/>
	<xsl:decimal-format name="european" decimal-separator="," grouping-separator="."/>
	<!-- Variablen - Deklarationen -->
	<xsl:variable name="zerostr" select="string('                                                                                                                                                                                                                                                      ')" />
	<xsl:variable name="LastPidPos" select="14"/>
	<!-- Parameter -->
	<xsl:param name="alpha"  select="0"/>
	<xsl:param name="prefix" select="'#'"/>
	<!-- Key Definitionen -->
	<xsl:key name="GetCatWithID" match="category" use="@id"/>
	<!-- Hilfstemplate zum Herauschreiben einer PID -->
	<xsl:template name="WritePID">
		<xsl:param name="PID"/>
		<xsl:if test="string-length($PID) &gt; $LastPidPos">
			<xsl:variable name="StartPos" select="string-length($PID) - $LastPidPos"/>
			<xsl:value-of select="substring($PID, $StartPos)"/>
		</xsl:if>
		<xsl:if test="string-length($PID) &lt;= $LastPidPos">
			<xsl:value-of select="concat(substring($zerostr, 1, $LastPidPos - string-length($PID) + 1), $PID)"/>
		</xsl:if>
	</xsl:template>
	<!-- Transformationsteil zum Wandel von RSXML nach KOR -->
	<xsl:template match="robostation">
		<xsl:for-each select="measurements">
			<xsl:for-each select="mfolder">
				<xsl:variable name="x_offset" select="sum(@x_offset)"/>
				<xsl:variable name="y_offset" select="sum(@y_offset)"/>
				<xsl:variable name="z_offset" select="sum(@z_offset)"/>
				<xsl:for-each select="polygon">
					<xsl:variable name="polycatids" select="@categories"/>
					<xsl:for-each select="point">
						<!-- Punkt ID Ausgabe -->
						<xsl:if test="$alpha='0'">
							<xsl:call-template name="WritePID">
								<xsl:with-param name="PID" select="@id"/>
							</xsl:call-template>
						</xsl:if>
						<xsl:if test="$alpha='1'">
							<xsl:if test="@name">
								<xsl:call-template name="WritePID">
									<xsl:with-param name="PID" select="@name"/>
								</xsl:call-template>
							</xsl:if>
							<xsl:if test="not(@name)">
								<xsl:variable name="NewPID" select="concat($prefix, @id)"/>
								<xsl:call-template name="WritePID">
									<xsl:with-param name="PID" select="$NewPID"/>
								</xsl:call-template>
							</xsl:if>
						</xsl:if>
						<!-- Punkt-Koordinate Ausgabe -->
						<xsl:variable name="x" select="format-number(@x + $x_offset, '#0.0000')"/>
						<xsl:variable name="y" select="format-number(@y + $y_offset, '#0.0000')"/>
						<xsl:variable name="z" select="format-number(@z + $z_offset, '#0.0000')"/>
						<xsl:value-of select="concat(substring($zerostr, 1, 15 - string-length($y)), $y)"/>
						<xsl:value-of select="concat(substring($zerostr, 1, 15 - string-length($x)), $x)"/>
						<xsl:value-of select="concat(substring($zerostr, 1, 11 - string-length($z)), $z)"/>
						<xsl:text> </xsl:text>
						<!-- Kategorie Ausgabe -->
						<xsl:variable name="pointcatids" select="@categories"/>

						<xsl:choose>
							<xsl:when test="string-length($polycatids) &gt; 0">
								<xsl:choose>
									<xsl:when test="contains($polycatids, ' ')">
										<xsl:variable name="catid" select="substring-before($polycatids, ' ')"/>
										<xsl:for-each select="/robostation/category_ref">
											<xsl:for-each select="key('GetCatWithID', $catid)">
												<xsl:value-of select="@name"/>
											</xsl:for-each>
										</xsl:for-each>
									</xsl:when>
									<xsl:otherwise>
										<xsl:for-each select="/robostation/category_ref">
											<xsl:for-each select="key('GetCatWithID', $polycatids)">
												<xsl:value-of select="@name"/>
											</xsl:for-each>
										</xsl:for-each>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:when>
							<xsl:otherwise>
								<xsl:choose>
									<xsl:when test="contains($pointcatids, ' ')">
										<xsl:variable name="catid" select="substring-before($pointcatids, ' ')"/>
										<xsl:for-each select="/robostation/category_ref">
											<xsl:for-each select="key('GetCatWithID', $catid)">
												<xsl:value-of select="@name"/>
											</xsl:for-each>
										</xsl:for-each>
									</xsl:when>
									<xsl:otherwise>
										<xsl:for-each select="/robostation/category_ref">
											<xsl:for-each select="key('GetCatWithID', $pointcatids)">
												<xsl:value-of select="@name"/>
											</xsl:for-each>
										</xsl:for-each>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:otherwise>
						</xsl:choose>
						<!-- Polygon Information + -> Verbindung von Punkten zu Polygonen -->
						<xsl:if test="last() &gt; 1">
							<xsl:if test="position() != last()">
								<xsl:text>+</xsl:text>
							</xsl:if>
						</xsl:if>
						<xsl:text>&#13;&#10;</xsl:text>
					</xsl:for-each>
				</xsl:for-each>
			</xsl:for-each>
		</xsl:for-each>
	</xsl:template>
</xsl:stylesheet>
